CONFEDERACIÓN DE AJEDREZ PARA AMÉRICA - INICIO

### ÚLTIMAS NOTICIAS

Dic 03, 2015 27

#### LISTA DE ELO FIDE DICIEMBRE 2015

in FIDE
Lista de Elo FIDE 1 de Noviembre de 2015 Lista de Elo FIDE Ajedrez Rápido 1 de Noviembre de 2015 Lista de Elo FIDE Ajedrez Blitz 1 de Noviembre de 2015 Leer Mas...
Dic 03, 2015 15

#### LXII CAMPEONATO NACIONAL E INTERNACIONAL ABIERTO MEXICANO DE AJEDREZ

in México
DESCARGAR CONVOCATORIA PDF Leer Mas...
Dic 03, 2015 20

#### CUBANO DOMÍNGUEZ PRETENDE BRILLAR EN PRÓXIMO MEMORIAL CAPABLANCA

in Cuba
La Habana, 2 dic (PL) El Memorial Capablanca es un torneo que se le ha resistido en los últimos años al Gran Maestro cubano Leinier Domínguez, pero según declaró hoy el jugador, para la edición 2016… Leer Mas...
Dic 03, 2015 17

#### SE LE PUEDE GANAR A CARLSEN, DICE CUBANO DOMÍNGUEZ

in Cuba
La Habana, 2 dic (PL) Para el Gran Maestro cubano Leinier Domínguez no es imposible destronar al actual campeón mundial de ajedrez, el noruego Magnus Carlsen, y más de un candidato lo puede hacer.… Leer Mas...
Dic 01, 2015 64

#### LEINIER SUBE TRES LUGARES EN EL RANKING MUNDIAL

in Cuba
La Habana, 30 nov (RHC) El Gran Maestro (GM) cubano Leinier Domínguez avanzó del puesto 27 al 24 en el ranking mundial de ajedrez , según dio a conocer este lunes la federación internacional de esta… Leer Mas...
Dic 01, 2015 64

#### ASCIENDE CUBANO LÁZARO BRUZÓN EN RANKING MUNDIAL DE AJEDREZ

in Cuba
Berna, 30 nov.- El cubano Lázaro Bruzón ganó 15 puestos en el ranking mundial de ajedrez este mes y ascendió al 76, con dos mil 666 puntos Elo, divulgó hoy la Federación Internacional de la… Leer Mas...
Nov 30, 2015 59

#### EVENTS INFORMATION

in FIDE
The Confederation of Chess for America will like to inform you that the Female Continental Championship, Mexico 2015 cycle was cancelled due to force majoure by Huricane Patricia, it will now be held… Leer Mas...
Nov 30, 2015 80

#### INFORMACIÓN DE EVENTOS

in FIDE
La Confederación de Ajedrez para América informa que el Campeonato Continental Femenino ciclo 2015 que debía efectuarse en México y que fue cancelado por fuerza mayor a causa del huracán Patricia se… Leer Mas...
Nov 30, 2015 2382

#### SEMINARIO DE ARBITRAJE POR INTERNET VÁLIDO PARA NORMA DE ÁRBITRO FIDE (ORGANIZA LA CONFEDERACIÓN DE AJEDREZ PARA AMÉRICA) + INSCRITOS

in FIDE
La Confederación de Ajedrez para América (CCA) organiza un Seminario de Arbitraje por Internet válido para Norma de Árbitro FIDE del 1 - 6 de Diciembre de 2015, bajo los auspicios de la FIDE. El… Leer Mas...
Nov 26, 2015 1705

#### CURSO MASTER DEL PROGRAMA SWISS MANAGER POR INTERNET (NOVIEMBRE) + INSCRITOS

in FIDE
CURSO MASTER DEL PROGRAMA SWISS MANAGER POR INTERNET Seminario diseñado para federaciones de América, donde se les enseñara de básico a avanzado el programa líder en emparejamiento a nivel mundial,… Leer Mas...
Nov 22, 2015 211

#### CUBA ASPIRA A MEDALLA EN LA PRÓXIMA OLIMPIADA DE AJEDREZ

in Cuba
Cuba aspira a obtener una medalla en la próxima Olimpiada de Ajedrez, que se disputará en 2016 en Bakú, la capital de Azerbaiyán, según dijo hoy en La Habana el Gran Maestro Leinier Domínguez, figura… Leer Mas...
Nov 19, 2015 128

#### HOY SE CELEBRA EL 127º ANIVERSARIO DEL NACIMIENTO DE CAPABLANCA

in Cuba
Por Dr. Uvencio Blanco Hernández Caracas, 19.11.2015. Recuerdo que en 1988 siendo entrevistado en un programa deportivo en Venezolana de Televisión (VTV), por don Roberto Ribeiro a quien se le… Leer Mas...
Nov 17, 2015 302

#### CAMPEONATO CENTROAMERICANO Y DEL CARIBE DE AJEDREZ FEMENINO (EL SALVADOR, SAN SALVADOR, 9-15 NOVEMBRE 2015) - RESULTADOS FINALES

in RESULTADOS 2015
Clasificación Final después de 7 rondas Rk. No.Ini. Nombre FED Elo Pts. Des 1 Des 2 Des 3 Des 4 n w we w-we K elo+/- 1 2 WIM Llaudy Pupo Lisandra CUB 2292 6,0 0,0 30,5 22,0 25,5 7 6 5,31 0,69 20 13,8… Leer Mas...
Nov 16, 2015 264

#### PRESENTACIÓN FESTIVAL SUDAMERICANO DE LA JUVENTUD DEL AJEDREZ

in Bolivia
Nov 14, 2015 2319

#### SEMINARIO DE ORGANIZADORES INTERNACIONALES POR INTERNET PARA AMÉRICA + LISTA DE PARTICIPANTES

in FIDE
1. Participación: Hasta 25 participantes de países del Continente Americano. La fecha límite para las inscripciones es el viernes 16 Octubre o hasta completar 25 participantes. 2. Calendario: *… Leer Mas...
Nov 13, 2015 241

#### TORNEO ZONAL FEMENINO 2.5 (BUENOS AIRES, ARGENTINA 6 - 13 NOVIEMBRE) - RESULTADOS FINALES

in RESULTADOS 2015
Clasificación Final después de 9 rondas Rk. No.Ini. Nombre FED Elo Pts. Des 1 Des 2 Des 3 K elo+/- 1 1 IM Lujan Carolina ARG 2378 7,5 0,0 42,0 37,25 10 3,3 2 3 WIM Zuriel Marisa ARG 2231 7,0 0,0 42,5… Leer Mas...
Nov 13, 2015 135

#### LORENA Y ANDREA CAEN EN EL C.A. Y DEL CARIBE

in El Salvador
Ambas cuscatlecas eran las únicas invictas en el Campeonato Centroamericano y del Caribe Femenino 2015 con dos fechas ya realizadas. La Maestra Internacional Femenina (WIM por sus siglas en inglés)… Leer Mas...
Nov 13, 2015 95

#### DOS SALVADOREÑAS INVICTAS HASTA EL MOMENTO

in El Salvador
La Maestra Internacional Femenina (WIM) Lorena Zepeda se encuentra hasta el momento con dos victorias en el Campeonato Centroamericano y del Caribe Femenino 2015 finalizada la primera jornada doble.… Leer Mas...
Nov 10, 2015 184

#### ARRANCÓ EL CENTROAMERICANO Y DEL CARIBE FEMENINO 2015

in El Salvador
La Maestra Internacional Femenina (WIM) Lorena Zepeda debutó con victoria en la jornada inaugural ante la nacional Camila Abarca del Campeonato Centroamericano y del Caribe Femenino 2015 que se… Leer Mas...
Nov 10, 2015 167

#### CAMPEONATO ZONAL 2.3 FEMENINO 2015 (MANAGUAS, NICARAGUA 3 A 9 9 NOVIEMBRE 2015) - RESULTADOS FINALES

in RESULTADOS 2015
Clasificación Final después de 9 rondas Rk. No.Ini. Nombre FED Elo Pts. Des 1 Des 2 Des 3 Des 4 n w we w-we K elo+/- 1 4 WGM Marrero Lopez Yaniet CUB 2279 8,0 0,0 44,5 35,5 7,0 9 8 6,70 1,30 20 26,0… Leer Mas...
Nov 08, 2015 113

#### TOBAR SE LLEVA EL ÚLTIMO ABIERTO

in El Salvador
Jorge Tobar (izquierda) sacó un tabla ante Marlon Vásquez (derecha) en la última fecha del IV Campeonato Abierto 2015. Se realizó la última fecha del IV Campeonato Abierto del 2015, donde los ojos… Leer Mas...

### RESULTADOS DE EVENTOS

### RESULTADOS 2015

Nov 17, 2015 302

#### CAMPEONATO CENTROAMERICANO Y DEL CARIBE DE AJEDREZ FEMENINO (EL SALVADOR, SAN SALVADOR, 9-15 NOVEMBRE 2015) - RESULTADOS FINALES

Nov 13, 2015 241

#### TORNEO ZONAL FEMENINO 2.5 (BUENOS AIRES, ARGENTINA 6 - 13 NOVIEMBRE) - RESULTADOS FINALES

Nov 10, 2015 167

#### CAMPEONATO ZONAL 2.3 FEMENINO 2015 (MANAGUAS, NICARAGUA 3 A 9 9 NOVIEMBRE 2015) - RESULTADOS FINALES

Sep 01, 2015 434

#### CAMPEONATO PANAMERICANO SENIOR + 50 (PORLAMAR, VENEZUELA- 21-29 AGOSTO 2015) - RESULTADOS FINALES

Sep 01, 2015 413

#### CAMPEONATO PANAMERICANO SENIOR + 65 (PORLAMAR, VENEZUELA- 21-29 AGOSTO 2015) - RESULTADOS FINALES

Sep 01, 2015 385

#### CAMPEONATO CENTROAMERICANO SUB 20 FEMENINO (PORLAMAR, VENEZUELA- 21-29 AGOSTO 2015) - RESULTADOS FINALES

Sep 01, 2015 406

#### CAMPEONATO CENTROAMERICANO SUB 20 ABSOLUTO (PORLAMAR, VENEZUELA, 21-29 AGOSTO 2015) - RESULTADOS FINALES

### RESULTADOS 2014

Dic 31, 2014 2102

#### V COPA LATINOAMERICANA DE AJEDREZ (GUAYAQUIL, ECUADOR, 26 - 31 DICIEMBRE 2014) RESULTADOS FINALES

Dic 22, 2014 1466

#### CAMPEONATO CENTROAMERICANO Y DEL CARIBE U20 (SAN JOSÉ, COSTA RICA, 16-23 DICIEMBRE 2014) RESULTADOS FINALES

Dic 21, 2014 1362

#### CAMPEONATO PANAMERICANO SENIOR +50 Y +65 AÑOS (SAO PAULO, BRASIL 17-21 DICIEMBRE 2014) RESULTADOS FINALES

Dic 20, 2014 1671

#### COPA BOLIVARIANA FIDE CATEGORÍA A (LIMA, PERU, 15 -19 DICIEMBRE 2014) - RESULTADOS FINALES

Oct 27, 2014 2972

#### CAMPEONATO CONTINENTAL DE LAS AMÉRICAS 2014 (RIO GRANDE DO NORTE, BRASIL, 18 AL 26 OCTUBRE 2014) RESULTADOS FINALES

Oct 09, 2014 1907

#### FESTIVAL CENTROAMERICANO Y DEL CARIBE DE LA JUVENTUD U18 ABSOLUTO (PALMIRA, VALLE DEL CAUCA, COLOMBIA, 3-8 OCTUBRE) RESULTADOS FINALES

Sep 15, 2014 2924

#### FESTIVAL SUDAMERICANO DE LA JUVENTUD (MONTEVIDEO, URUGUAY) 8-14 SEPTIEMBRE 2014 - RESULTADOS FINALES

### BUSCADOR DE NOTICIAS

### siguenos en facebook

### FIDE

Dic 03, 2015 27

#### LISTA DE ELO FIDE DICIEMBRE 2015

Lista de Elo FIDE 1 de Noviembre de 2015 Lista de Elo FIDE Ajedrez Rápido 1 de Noviembre…
Nov 30, 2015 59

#### EVENTS INFORMATION

The Confederation of Chess for America will like to inform you that the Female…
Nov 30, 2015 80

#### INFORMACIÓN DE EVENTOS

La Confederación de Ajedrez para América informa que el Campeonato Continental Femenino…
Nov 30, 2015 2382

#### SEMINARIO DE ARBITRAJE POR INTERNET VÁLIDO PARA NORMA DE ÁRBITRO FIDE (ORGANIZA LA CONFEDERACIÓN DE AJEDREZ PARA AMÉRICA) + INSCRITOS

La Confederación de Ajedrez para América (CCA) organiza un Seminario de Arbitraje por…
Nov 26, 2015 1705

#### CURSO MASTER DEL PROGRAMA SWISS MANAGER POR INTERNET (NOVIEMBRE) + INSCRITOS

CURSO MASTER DEL PROGRAMA SWISS MANAGER POR INTERNET Seminario diseñado para federaciones…
Nov 14, 2015 2319

#### SEMINARIO DE ORGANIZADORES INTERNACIONALES POR INTERNET PARA AMÉRICA + LISTA DE PARTICIPANTES

1. Participación: Hasta 25 participantes de países del Continente Americano. La fecha…

### NOTICIAS FEDERACIONES

### VISITAS

37718322
Today
Yesterday
This Week
Last Week
This Month
Last Month
All days
2877
3628
16200
6916220
10462
127265
37718322

Your IP: 217.114.230.27
Server Time: 2015-12-03 19:15:40
Visitors Counter